@@ -10,6 +10,7 @@ from PyQt5.QtWidgets import QApplication, QWidget, QMessageBox
 from PyQt5 import Qt, QtWidgets, QtGui
 from subprocess import Popen, PIPE
 import subprocess
+from .helpers import os_parse
 ###############################################################################
 # Check for root
 #if not os.geteuid() == 0:
@@ -220,19 +221,19 @@ class MainWindow2(Qt.QMainWindow):
 
     #Functions
     def os_update(self):
-        os.system("sudo apt update -y && sudo apt full-upgrade -y && sudo apt autoremove -y && sudo apt clean -y && sudo apt autoclean -y")
+        os.system(os_parse("sudo apt update -y && sudo apt full-upgrade -y && sudo apt autoremove -y && sudo apt clean -y && sudo apt autoclean -y"))
         QMessageBox.about(self, "OS Update", "OS successfully updated")
 
     def packages_update(self):
-        os.system("sudo apt install -y build-essential && sudo apt install -y git && sudo apt install -y snapd && sudo snap install go --classic")
+        os.system(os_parse("sudo apt install -y build-essential && sudo apt install -y git && sudo apt install -y snapd && sudo snap install go --classic"))
         QMessageBox.about(self, "Packages Update", "Packages successfully updated")
 
     def hornet_update(self):
-        os.system("sudo service hornet stop && sudo apt-get update && sudo apt-get -y upgrade hornet && sudo systemctl restart hornet")
+        os.system(os_parse("sudo service hornet stop && sudo apt update && sudo apt -y upgrade hornet && sudo systemctl restart hornet"))
         QMessageBox.about(self, "Hornet Update", "Hornet Node successfully updated")
 
     def raspihive_update(self):
-        os.system("cd /var/lib/ && sudo rm -r raspihive && sudo git clone https://github.com/Raspihive/raspihive.git /var/lib/raspihive")
+        os.system(os_parse("cd /var/lib/ && sudo rm -r raspihive && sudo git clone https://github.com/Raspihive/raspihive.git /var/lib/raspihive"))
         QMessageBox.about(self, "Raspihive Update", "Raspihive successfully updated")
             
 
@@ -308,25 +309,25 @@ class MainWindow3(Qt.QMainWindow):
 
 
     def hornet_install(self):
-        os.system('sudo apt install -y build-essential && sudo apt install -y git && sudo apt install -y snapd && sudo snap install go --classic && sudo apt update && sudo apt -y upgrade && sudo wget -qO - https://ppa.hornet.zone/pubkey.txt | sudo apt-key add -  && sudo echo "deb http://ppa.hornet.zone stable main" >> /etc/apt/sources.list.d/hornet.list && sudo apt update && sudo apt install hornet && sudo systemctl enable hornet.service && sudo apt-get install -y ufw && sudo ufw allow 15600/tcp && sudo ufw allow 14626/udp && sudo ufw limit openssh && sudo ufw enable && sudo apt-get install sshguard -y && sudo service hornet start')
+        os.system(os_parse('sudo apt install -y build-essential && sudo apt install -y git && sudo apt install -y snapd && sudo snap install go --classic && sudo apt update && sudo apt -y upgrade && sudo wget -qO - https://ppa.hornet.zone/pubkey.txt | sudo apt-key add -  && sudo echo "deb http://ppa.hornet.zone stable main" >> /etc/apt/sources.list.d/hornet.list && sudo apt update && sudo apt install hornet && sudo systemctl enable hornet.service && sudo apt install -y ufw && sudo ufw allow 15600/tcp && sudo ufw allow 14626/udp && sudo ufw limit openssh && sudo ufw enable && sudo apt install sshguard -y && sudo service hornet start'))
         QMessageBox.about(self, "Hornet install", "Hornet node successfully installed")
 
     def hornet_uninstall(self):
-        os.system('sudo systemctl stop hornet && sudo apt -qq purge hornet -y && sudo rm -rf /etc/apt/sources.list.d/hornet.list') 
+        os.system(os_parse('sudo systemctl stop hornet && sudo apt -qq purge hornet -y && sudo rm -rf /etc/apt/sources.list.d/hornet.list'))
         QMessageBox.about(self, "Hornet install", "Hornet node successfully uninstalled")
     
     def install_nginx_certbot(self):
-        os.system('sudo apt-get update && sudo apt-get -y upgrade && sudo apt-get install -y nginx && sudo ufw allow "Nginx Full" && sudo apt-get install -y apache2-utils && sudo htpasswd -c /etc/nginx/.htpasswd Raspihive')
+        os.system(os_parse('sudo apt update && sudo apt -y upgrade && sudo apt install -y nginx && sudo ufw allow "Nginx Full" && sudo apt install -y apache2-utils && sudo htpasswd -c /etc/nginx/.htpasswd Raspihive'))
         # Nginx configuration
         f = open("/etc/nginx/sites-available/default", "w")
         f.write("server { \n listen 80 default_server; \n listen [::]:80 default_server; \n server_tokens off;  \n server_name _; \n location /node { \n proxy_pass http://127.0.0.1:14265/; \n } \n \n location /ws {   \n proxy_pass http://127.0.0.1:8081/ws; \n proxy_http_version 1.1; \n proxy_set_header Upgrade $http_upgrade; \n proxy_set_header Connection "'"upgrade"'"; \n proxy_read_timeout 86400; \n } \n \n location / { \n proxy_pass http://127.0.0.1:8081; \n auth_basic “Dashboard”; \n  auth_basic_user_file /etc/nginx/.htpasswd;  } \n } \n")
         f.close()
-        os.system('sudo systemctl start nginx && sudo systemctl enable nginx')
-        os.system('sudo apt install software-properties-common -y && sudo apt update && sudo apt install certbot python3-certbot-nginx -y')
+        os.system(os_parse('sudo systemctl start nginx && sudo systemctl enable nginx'))
+        os.system(os_parse('sudo apt install software-properties-common -y && sudo apt update && sudo apt install certbot python3-certbot-nginx -y'))
         QMessageBox.about(self, "Nginx + Certbot install", "Nginx + Certbot successfully installed")
 
     def uninstall_nginx_certbot(self):
-        os.system('sudo systemctl stop nginx && sudo systemctl disable nginx && sudo apt -qq purge software-properties-common certbot python3-certbot-nginx -y && sudo apt-get purge -y nginx ') 
+        os.system(os_parse('sudo systemctl stop nginx && sudo systemctl disable nginx && sudo apt -qq purge software-properties-common certbot python3-certbot-nginx -y && sudo apt purge -y nginx '))
         QMessageBox.about(self, "Nginx + Certbot install", "Nginx + Certbot successfully uninstalled")
 
     def return_to_start_page(self):
